@@ -14,24 +14,13 @@ The command details are shown by as follows:
 
 =head1 VERSION
 
-Version 1.031
+Version 1.04
 
 =cut
 
-our $VERSION = '1.031';
+our $VERSION = '1.04';
 
 
-=head1 SYNOPSIS
-
-Quick summary of what the module does.
-
-Perhaps a little code snippet.
-
-    use cli::crosstable;
-
-    my $foo = cli::crosstable->new();
-    ...
-
 =head1 AUTHOR
 
 "Toshiyuki Shimono", C<< <bin4tsv at gmail.com> >>
